need some more studies:

https://sysdig.com/blog/prometheus-metrics/

Dashboard
https://github.com/topics/grafana-dashboard?o=desc&s=updated

Using log files
https://grafana.com/docs/loki/latest/getting-started/
